@@ -173,7 +173,7 @@ use common::sense;
 use base 'Exporter';
 
 BEGIN {
-   our $VERSION = 4.4;
+   our $VERSION = 4.5;
 
    our @AIO_REQ = qw(aio_sendfile aio_seek aio_read aio_write aio_open aio_close
                      aio_stat aio_lstat aio_unlink aio_rmdir aio_readdir aio_readdirx
@@ -194,7 +194,7 @@ BEGIN {
                        nreqs nready npending nthreads
                        max_poll_time max_poll_reqs
                        sendfile fadvise madvise
-                       mmap munmap munlock munlockall);
+                       mmap munmap mremap munlock munlockall);
 
    push @AIO_REQ, qw(aio_busy); # not exported
 
@@ -287,6 +287,7 @@ documentation.
    IO::AIO::fadvise $fh, $offset, $len, $advice
    IO::AIO::mmap $scalar, $length, $prot, $flags[, $fh[, $offset]]
    IO::AIO::munmap $scalar
+   IO::AIO::mremap $scalar, $new_length, $flags[, $new_address]
    IO::AIO::madvise $scalar, $offset, $length, $advice
    IO::AIO::mprotect $scalar, $offset, $length, $protect
    IO::AIO::munlock $scalar, $offset = 0, $length = undef
@@ -406,7 +407,7 @@ your system are, as usual, C<0>):
 
 C<O_ASYNC>, C<O_DIRECT>, C<O_NOATIME>, C<O_CLOEXEC>, C<O_NOCTTY>, C<O_NOFOLLOW>,
 C<O_NONBLOCK>, C<O_EXEC>, C<O_SEARCH>, C<O_DIRECTORY>, C<O_DSYNC>,
-C<O_RSYNC>, C<O_SYNC>, C<O_PATH>, C<O_TMPFILE>, and C<O_TTY_INIT>.
+C<O_RSYNC>, C<O_SYNC>, C<O_PATH>, C<O_TMPFILE>, C<O_TTY_INIT> and C<O_ACCMODE>.
 
 
 =item aio_close $fh, $callback->($status)
@@ -791,10 +792,10 @@ flags will also be passed to the callback, possibly modified):
 
 =item IO::AIO::READDIR_DENTS
 
-When this flag is off, then the callback gets an arrayref consisting of
-names only (as with C<aio_readdir>), otherwise it gets an arrayref with
-C<[$name, $type, $inode]> arrayrefs, each describing a single directory
-entry in more detail.
+Normally the callback gets an arrayref consisting of names only (as
+with C<aio_readdir>). If this flag is set, then the callback gets an
+arrayref with C<[$name, $type, $inode]> arrayrefs, each describing a
+single directory entry in more detail:
 
 C<$name> is the name of the entry.
 
@@ -804,9 +805,9 @@ C<IO::AIO::DT_UNKNOWN>, C<IO::AIO::DT_FIFO>, C<IO::AIO::DT_CHR>, C<IO::AIO::DT_D
 C<IO::AIO::DT_BLK>, C<IO::AIO::DT_REG>, C<IO::AIO::DT_LNK>, C<IO::AIO::DT_SOCK>,
 C<IO::AIO::DT_WHT>.
 
-C<IO::AIO::DT_UNKNOWN> means just that: readdir does not know. If you need to
-know, you have to run stat yourself. Also, for speed reasons, the C<$type>
-scalars are read-only: you can not modify them.
+C<IO::AIO::DT_UNKNOWN> means just that: readdir does not know. If you need
+to know, you have to run stat yourself. Also, for speed/memory reasons,
+the C<$type> scalars are read-only: you must not modify them.
 
 C<$inode> is the inode number (which might not be exact on systems with 64
 bit inode numbers and 32 bit perls). This field has unspecified content on
@@ -827,12 +828,14 @@ short names are tried first.
 =item IO::AIO::READDIR_STAT_ORDER
 
 When this flag is set, then the names will be returned in an order
-suitable for stat()'ing each one. That is, when you plan to stat()
-all files in the given directory, then the returned order will likely
-be fastest.
+suitable for stat()'ing each one. That is, when you plan to stat() most or
+all files in the given directory, then the returned order will likely be
+faster.
 
-If both this flag and C<IO::AIO::READDIR_DIRS_FIRST> are specified, then
-the likely dirs come first, resulting in a less optimal stat order.
+If both this flag and C<IO::AIO::READDIR_DIRS_FIRST> are specified,
+then the likely dirs come first, resulting in a less optimal stat order
+for stat'ing all entries, but likely a more optimal order for finding
+subdirectories.
 
 =item IO::AIO::READDIR_FOUND_UNKNOWN
 
@@ -2158,6 +2161,29 @@ Example:
 
 Removes a previous mmap and undefines the C<$scalar>.
 
+=item IO::AIO::mremap $scalar, $new_length, $flags = MREMAP_MAYMOVE[, $new_address = 0]
+
+Calls the Linux-specific mremap(2) system call. The C<$scalar> must have
+been mapped by C<IO::AIO::mmap>, and C<$flags> must currently either be
+C<0> or C<IO::AIO::MREMAP_MAYMOVE>.
+
+Returns true if successful, and false otherwise. If the underlying mmapped
+region has changed address, then the true value has the numerical value
+C<1>, otherwise it has the numerical value C<0>:
+
+   my $success = IO::AIO::mremap $mmapped, 8192, IO::AIO::MREMAP_MAYMOVE
+      or die "mremap: $!";
+
+   if ($success*1) {
+      warn "scalar has chanegd address in memory\n";
+   }
+
+C<IO::AIO::MREMAP_FIXED> and the C<$new_address> argument are currently
+implemented, but not supported and might go away in a future version.
+
+On systems where this call is not supported or is not emulated, this call
+returns falls and sets C<$!> to C<ENOSYS>.
+
 =item IO::AIO::munlock $scalar, $offset = 0, $length = undef
 
 Calls the C<munlock> function, undoing the effects of a previous
